clear

warning off MATLAB:divideByZero;
warning off MATLAB:singularMatrix;

format compact;
format short g;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% CMLE MODEL %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%           TOBIT             %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
% SIMULATION DESIGN;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
% ystar_{it} = d_{it} \beta1 + y_{i,t-1} \beta2 + \alpha2_{i} + \epsilon2_{it};
% d_{it} = x1_{it} \theta + \alpha_1{i} + \epsilon1_{it};
% y_{it} = 1 {ystar_{it} > 0} ystar_{it};
% (\epsilon1_{it},\epsilon2_{it}) ~ i.i.d N((0,0),\sigma*(1 \rho; \rho 1));
% x1_{it} ~ i.i.d N(0,\sigma2x);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
% ADDITIONAL NOTATION;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
% \beta = (\beta1, \beta2, \rho)
% \alpha1 = (\alpha1_{1}, ..., \alpha1_{n});
% \alpha2 = (\alpha2_{1}, ..., \alpha2_{n});
% \gamma = (\theta, \alpha1);
% \delta = (\beta, \alpha2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
% REPARAMETRIZATION;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
% h = 1/ \sigma;
% \betah = h*\beta;
% \alpha2h = h*\alpha2;
% \deltah = (h, \betah, \alpha2h);


% CASE 2: FIXED EFFECTS;
% (\alpha_{1i},\alpha_{2i}) ~ sqrt(T)*((x_{21} + ... + x_{2T})/T -1) + sqrt(1 - sigma2x2) * i.i.d. N((0,0),(1 \xi; \xi 1));

% VALUES OF THE PARAMETERS;

B = 1000;
N = 100;
T = 3;
p2 = 3;

sigma2x = 1;
sigma0 = 1;
beta1 = 1;
beta2 = .5;
theta1 = 1;
rho = 0.6;
sigma = 1 + (T - 1) * rho^2 / T;
theta = [theta1; rho];
eta = 0;
xi = 1;

mux = [0];
sigmax = sigma2x*[1];
mualpha = [0 ; 0];
sigmaalpha = [1 xi; xi 1];
muepsilon = [0 ; 0];
sigmaepsilon = sigma*[1 rho; rho sigma];


% GENERATING MATRICES FOR FIXED EFFECTS;
D = kron([1:N]',ones(T,1)); % Individual id
FE = sparse(dummyvar(D));   % Matrix of individual dummy variables


% SIMULATION;

options = optimset('GradObj', 'on');
tic, % Start the clock
for i = 1:B,

    disp(i);

% GENERATING THE SAMPLE;    
     x1 = mvnrnd(mux,sigmax,N*T);
     xx1 = reshape(x1,T,N);
 
     xx10 = sqrt(sigma2x)*randn(1,N);
 
     alpha = mvnrnd(mualpha,sigmaalpha,N);
     alpha1 = kron(FE' * (x1 - mux(1,1)),ones(T,1))/ sqrt(T)  + (sqrt(1 - sigma2x)) * kron(alpha(:,1),ones(T,1));
     alpha2 = kron(FE' * (x1 - mux(1,1)),ones(T,1))/ sqrt(T)  + (sqrt(1 - sigma2x)) * kron(alpha(:,2),ones(T,1));
     alpha1i = FE' * (x1 - mux(1,1))/ sqrt(T)  + (sqrt(1 - sigma2x)) * alpha(:,1);
     alpha2i = FE' * (x1 - mux(1,1))/ sqrt(T)  + (sqrt(1 - sigma2x)) * alpha(:,2);

     epsilon = mvnrnd(muepsilon,sigmaepsilon,N*T);
     epsilon1 = epsilon(:,1);
     epsilon2 = epsilon(:,2);

     ep2 = reshape(epsilon2,T,N);
     ep1 = reshape(epsilon1,T,N);
     ep20 = randn(1,N);
     ep10 = randn(1,N);

     d0 = theta1*xx10 + alpha1i' + ep10;
     yy0 = (d0*beta1 + alpha2i' + ep20 > 0) .* (d0*beta1 + alpha2i' + ep20);
     dd(1,:) = xx1(1,:)*theta1 + alpha1i' + ep1(1,:);
     yy(1,:) = real(beta1*dd(1,:) + beta2*yy0 + alpha2i' + ep2(1,:) > 0).*(beta1*dd(1,:) + beta2*yy0 + alpha2i' + ep2(1,:));
     for t = 2:T,
         dd(t,:) = xx1(t,:)*theta1 + alpha1i' + ep1(t,:);
         yy(t,:) = real(beta1*dd(t,:) + beta2*yy(t-1,:) + alpha2i' + ep2(t,:) > 0) .* (beta1*dd(t,:) + beta2*yy(t-1,:) + alpha2i' + ep2(t,:));
     end
    yylag = [yy0 ; yy(1:(T-1),:)];
    ylag = reshape(yylag,N*T,1);
    d = reshape(dd,T*N,1);
    y = reshape(yy,T*N,1);
    x2 = [d, ylag];

  
%%%%%%%%%%%%%%%%%;
% FIRST STAGE;
%%%%%%%%%%%%%%%%%;
    X1 = [x1,FE];
    gamma = X1\d;
    lambdahat = d - X1*gamma;
    thetahat(:,i) = gamma(1,1);
    mu1  = X1*gamma;

%%%%%%%%%%%%%%%%%;
% SECOND STAGE;
%%%%%%%%%%%%%%%%%;

% ELIMINATING INDIVIDUALS WITH ALL 0's;
    x1p = x1;
    x2p = [d, ylag, lambdahat];
    FEp = FE;
    dp  = d;
    yp  = y;
    lambdahatp = lambdahat;
    mu1p = mu1;
    for j = 1:N,
        I = find(D == j);
        if (mean(y(I)) == 0),
            dp(I) = NaN;
            x1p(I,:) = NaN;
            x2p(I,:) = NaN;
            FEp(I,:) = NaN;
            FEp(:,j) = NaN;
            alpha1(I) = NaN;
        end
    end
    I = find(isnan(dp));
    Dp = D;
    Dp(I) = [];
    Dp = recode(Dp);
    
    dp(I) = [];
    alpha1(I) = [ ];
    FEp(I,:) = [];
    x1p(I,:) = [];
    lambdahatp(I,:) = [];
    mu1p(I,:) = [];
    
    yp(I) = [ ];
    alpha2(I) = [ ];
    x2p(I,:) = [];

    I = find(isnan(FEp(1,:)'));
    FEp(:,I) = [];
    Np = size(FEp,2);
    NN1(i) = Np;
    
    % True control function
    lambda = dp - x1p*theta1 - alpha1;
    X1 = [x1p, FEp];
    

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
%%% TOBIT ESTIMATOR WITHOUT ACCOUNTING FOR ENDOGENEITY;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
    X2 = [x2p(:,1:(p2-1)), FEp];
    deltah0 = [1 ; X2\yp];
    deltah = fminunc('tobit', deltah0, options, yp, X2); % FE tobit
    H_mle0 = vc_tobit(yp,X2,deltah,Np);
    
   
    H_mle0 = jacobian(deltah) * H_mle0 * jacobian(deltah)';
    s2_mle0(:,i) = [diag(H_mle0(1:p2,1:p2));0];
    deltah = reparametrize(deltah);
    betahat_mle0(:,i) = [deltah(1:p2,1);0];
     
        
   

% MLE TOBIT (USING TRUE CONTROL FUNCTION AND INDIVIDUAL EFFECTS);
    X2 = [x2p(:,1:(p2-1)), lambda];
    deltah0 = X2\(yp - alpha2);
    deltah = fminunc('tobit2', deltah0, options, yp, X2, 1, alpha2); % FE tobit

    deltah = reparametrize(deltah);
    betahat_u0(:,i) = [1 ; deltah(1:p2,1)];    
    

% MLE TOBIT (USING TRUE CONTROL FUNCTION);
    X2 = [x2p(:,1:(p2-1)), lambda, FEp];
    deltah0 = [1 ; X2\yp];
    deltah = fminunc('tobit', deltah0, options, yp, X2); % FE tobit
    H_mle1 = vc_tobit(yp,X2,deltah,Np);

    H_mle1 = jacobian(deltah) * H_mle1 * jacobian(deltah)';
    s2_mle1(:,i) = diag(H_mle1(1:(p2+1),1:(p2+1)));
    deltah = reparametrize(deltah);
    betahat_mle1(:,i) = deltah(1:(p2+1),1);    
    


% FIXED EFFECTS IV LINEAR MODEL;
    X2 = [x2p, FEp];    
    delta = X2\yp;
    H_olsen = vc_olsen(yp,X2,delta);
    betahatolsen(:,i) = [delta(1:p2,1);0];
    s2_olsen(:,i) = [diag(H_olsen(1:p2,1:p2));0];
    
% MLE TOBIT;
    deltah0 = [1 ; X2\yp];
    deltah = fminunc('tobit', deltah0, options, yp, X2); % FE tobit
    betahhat_mle(:,i) = deltah(1:(p2+1),1);    
    
    h = deltah(1,1);
    delta = deltah(2:size(deltah,1),1);

    H_mle = avc_tobit(yp,X2,deltah,Np, lambdahatp, X1, mu1p);
%    H_mle = vc_tobit(yp,X2,deltah,Np);
    H_mle = jacobian(deltah) * H_mle * jacobian(deltah)';
    s2_mle(:,i) = diag(H_mle(1:(p2+1),1:(p2+1)));
    delta0 = reparametrize(deltah);
    betahat_mle(:,i) = delta0(1:(p2+1),1);    

    
    
% ANALYTICAL-M BC MLE TOBIT;    
    BIAS2(:,i) = bias_beta_tobit(yp,X2,deltah,Np,Dp);
    betahhatbc2(:,i) = betahhat_mle(:,i) - (1/T)*BIAS2(:,i);
    b1 = betahhatbc2(:,i);
    % Estimates of the alphas fixing beta at the BC estimate
    h = b1(1,1);
    mu1 = x2p*b1(2:size(b1,1),1);
    delta20 = deltah((p2+2):size(deltah,1),1);
    delta2 = fminunc('tobit2', delta20, options, yp, X2(:,(p2+1):size(X2,2)), h, mu1);
    deltahbc2 = [betahhatbc2(:,i); delta2];

   
    H_bc2 = avc_tobit(yp,X2,deltahbc2,Np, lambdahatp, X1, mu1p);
%    H_bc2 = vc_tobit(yp,X2,deltahbc2,Np);
    H_bc2 = jacobian(deltahbc2) * H_bc2 * jacobian(deltahbc2)';
    s2_bc2(:,i) = diag(H_bc2(1:(p2+1),1:(p2+1)));
    delta0bc2 = reparametrize(deltahbc2);
    betahatbc2(:,i) = delta0bc2(1:(p2+1),1);    
    
% ANALYTICAL BC MLE TOBIT;    
    BIAS1(:,i) = bias_beta_tobit_mle(yp,X2,deltah,Np,Dp);
    betahhatbc1(:,i) = betahhat_mle(:,i) - (1/T)*BIAS1(:,i);
    b1 = betahhatbc1(:,i);
    % Estimates of the alphas fixing beta at the BC estimate
    h = b1(1,1);
    mu1 = x2p*b1(2:size(b1,1),1);
%    delta20 = deltah((p2+2):size(deltah,1),1);
    delta20 = delta2;
    delta2 = fminunc('tobit2', delta20, options, yp, X2(:,(p2+1):size(X2,2)), h, mu1);
    deltahbc1 = [betahhatbc1(:,i); delta2];

   
    H_bc1 = avc_tobit(yp,X2,deltahbc1,Np, lambdahatp, X1, mu1p);
%    H_bc1 = vc_tobit(yp,X2,deltahbc1,Np);
    H_bc1 = jacobian(deltahbc1) * H_bc1 * jacobian(deltahbc1)';
    s2_bc1(:,i) = diag(H_bc1(1:(p2+1),1:(p2+1)));
    delta0bc1 = reparametrize(deltahbc1);
    betahatbc1(:,i) = delta0bc1(1:(p2+1),1);    

    
% ANALYTICAL 2 BC MLE TOBIT;    
    BIAS3(:,i) = bias_beta_tobit_mle2(yp,X2,deltah,Np,Dp);
    betahhatbc3(:,i) = betahhat_mle(:,i) - (1/T)*BIAS3(:,i);
    b1 = betahhatbc3(:,i);
    % Estimates of the alphas fixing beta at the BC estimate
    h = b1(1,1);
    mu1 = x2p*b1(2:size(b1,1),1);
    delta20 = deltah((p2+2):size(deltah,1),1);
    delta2 = fminunc('tobit2', delta20, options, yp, X2(:,(p2+1):size(X2,2)), h, mu1);
    deltahbc3 = [betahhatbc3(:,i); delta2];
 

    H_bc3 = avc_tobit2(yp,X2,deltahbc3,Np, lambdahatp, X1, mu1p);
%    H_bc3 = vc_tobit2(yp,X2,deltahbc3,Np);
    H_bc3 = jacobian(deltahbc3) * H_bc3 * jacobian(deltahbc3)';
    s2_bc3(:,i) = diag(H_bc3(1:(p2+1),1:(p2+1)));
    delta0bc3 = reparametrize(deltahbc3);
    betahatbc3(:,i) = delta0bc3(1:(p2+1),1);    

    
    
    
% REPORTING IN EACH SIMULATION;    

    disp('Betah');
    [mean(betahhat_mle,2)  mean(betahhatbc1,2) mean(betahhatbc2,2) mean(betahhatbc3,2)] 

    disp('Beta');
    [mean(betahat_mle1,2) mean(betahat_mle,2)  mean(betahatbc1,2) mean(betahatbc2,2) mean(betahatbc3,2)] 
    [mean(betahat_u0,2) mean(betahat_mle0,2)  mean(betahatolsen,2)]

    disp('Theta');
    [mean(thetahat)]

end
toc,


disp(size(betahat_mle));


disp('Table 1a: Coefficients sigma');
full([mean(betahat_mle0(1,:))/sqrt(sigma0)   median(betahat_mle0(1,:))/sqrt(sigma0)   std(betahat_mle0(1,:)/sqrt(sigma0))  (1 - mean((betahat_mle0(1,:) - 1.96*sqrt(s2_mle0(1,:)) <= sqrt(sigma0)) & (betahat_mle0(1,:) + 1.96*sqrt(s2_mle0(1,:)) >= sqrt(sigma0))))                     (1 - mean((betahat_mle0(1,:) - 1.65*sqrt(s2_mle0(1,:)) <= sqrt(sigma0)) & (betahat_mle0(1,:) + 1.65*sqrt(s2_mle0(1,:)) >= sqrt(sigma0))))                     (mean(sqrt(s2_mle0(1,:)))/std(betahat_mle0(1,:)))   median(abs(betahat_mle0(1,:)/sqrt(sigma0) - 1))     mean(T*NN1);...
      mean(betahat_mle(1,:))/sqrt(sigma0)    median(betahat_mle(1,:))/sqrt(sigma0)    std(betahat_mle(1,:)/sqrt(sigma0))   (1 - mean((betahat_mle(1,:) - 1.96*sqrt(s2_mle(1,:)) <= sqrt(sigma0)) & (betahat_mle(1,:) + 1.96*sqrt(s2_mle(1,:)) >= sqrt(sigma0))))                         (1 - mean((betahat_mle(1,:) - 1.65*sqrt(s2_mle(1,:)) <= sqrt(sigma0)) & (betahat_mle(1,:) + 1.65*sqrt(s2_mle(1,:)) >= sqrt(sigma0))))                         (mean(sqrt(s2_mle(1,:)))/std(betahat_mle(1,:)))     median(abs(betahat_mle(1,:)/sqrt(sigma0) - 1))      mean(T*NN1);...
      mean(betahatbc1(1,:))/sqrt(sigma0)     median(betahatbc1(1,:))/sqrt(sigma0)     std(betahatbc1(1,:)/sqrt(sigma0))    (1 - mean((betahatbc1(1,:) - 1.96*sqrt(s2_bc1(1,:)) <= sqrt(sigma0)) & (betahatbc1(1,:) + 1.96*sqrt(s2_bc1(1,:)) >= sqrt(sigma0))))                           (1 - mean((betahatbc1(1,:) - 1.65*sqrt(s2_bc1(1,:)) <= sqrt(sigma0)) & (betahatbc1(1,:) + 1.65*sqrt(s2_bc1(1,:)) >= sqrt(sigma0))))                           (mean(sqrt(s2_bc1(1,:)))/std(betahatbc1(1,:)))      median(abs(betahatbc1(1,:)/sqrt(sigma0) - 1))       mean(T*NN1) ;...
      mean(betahatbc2(1,:))/sqrt(sigma0)     median(betahatbc2(1,:))/sqrt(sigma0)     std(betahatbc2(1,:)/sqrt(sigma0))    (1 - mean((betahatbc2(1,:) - 1.96*sqrt(s2_bc2(1,:)) <= sqrt(sigma0)) & (betahatbc2(1,:) + 1.96*sqrt(s2_bc2(1,:)) >= sqrt(sigma0))))                           (1 - mean((betahatbc2(1,:) - 1.65*sqrt(s2_bc2(1,:)) <= sqrt(sigma0)) & (betahatbc2(1,:) + 1.65*sqrt(s2_bc2(1,:)) >= sqrt(sigma0))))                           (mean(sqrt(s2_bc2(1,:)))/std(betahatbc2(1,:)))      median(abs(betahatbc2(1,:)/sqrt(sigma0) - 1))       mean(T*NN1) ;...
      mean(betahatbc3(1,:))/sqrt(sigma0)     median(betahatbc3(1,:))/sqrt(sigma0)     std(betahatbc3(1,:)/sqrt(sigma0))    (1 - mean((betahatbc3(1,:) - 1.96*sqrt(s2_bc3(1,:)) <= sqrt(sigma0)) & (betahatbc3(1,:) + 1.96*sqrt(s2_bc3(1,:)) >= sqrt(sigma0))))                           (1 - mean((betahatbc3(1,:) - 1.65*sqrt(s2_bc3(1,:)) <= sqrt(sigma0)) & (betahatbc3(1,:) + 1.65*sqrt(s2_bc3(1,:)) >= sqrt(sigma0))))                           (mean(sqrt(s2_bc3(1,:)))/std(betahatbc3(1,:)))      median(abs(betahatbc3(1,:)/sqrt(sigma0) - 1))       mean(T*NN1) ])

disp('Table 1b: Coefficients beta1');
full([mean(betahat_mle0(2,:))/beta1   median(betahat_mle0(2,:))/beta1   std(betahat_mle0(2,:)/beta1)  (1 - mean((betahat_mle0(2,:) - 1.96*sqrt(s2_mle0(2,:)) <= beta1) & (betahat_mle0(2,:) + 1.96*sqrt(s2_mle0(2,:)) >= beta1)))                     (1 - mean((betahat_mle0(2,:) - 1.65*sqrt(s2_mle0(2,:)) <= beta1) & (betahat_mle0(2,:) + 1.65*sqrt(s2_mle0(2,:)) >= beta1)))                 (mean(sqrt(s2_mle0(2,:)))/std(betahat_mle0(2,:)))   median(abs(betahat_mle0(2,:)/beta1 - 1))     mean(T*NN1);...
      mean(betahat_mle1(2,:))/beta1   median(betahat_mle1(2,:))/beta1   std(betahat_mle1(2,:)/beta1)  (1 - mean((betahat_mle1(2,:) - 1.96*sqrt(s2_mle1(2,:)) <= beta1) & (betahat_mle1(2,:) + 1.96*sqrt(s2_mle1(2,:)) >= beta1)))                     (1 - mean((betahat_mle1(2,:) - 1.65*sqrt(s2_mle1(2,:)) <= beta1) & (betahat_mle1(2,:) + 1.65*sqrt(s2_mle1(2,:)) >= beta1)))                 (mean(sqrt(s2_mle1(2,:)))/std(betahat_mle1(2,:)))   median(abs(betahat_mle1(2,:)/beta1 - 1))     mean(T*NN1);...
      mean(betahat_mle(2,:))/beta1    median(betahat_mle(2,:))/beta1    std(betahat_mle(2,:)/beta1)   (1 - mean((betahat_mle(2,:) - 1.96*sqrt(s2_mle(2,:)) <= beta1) & (betahat_mle(2,:) + 1.96*sqrt(s2_mle(2,:)) >= beta1)))                         (1 - mean((betahat_mle(2,:) - 1.65*sqrt(s2_mle(2,:)) <= beta1) & (betahat_mle(2,:) + 1.65*sqrt(s2_mle(2,:)) >= beta1)))                     (mean(sqrt(s2_mle(2,:)))/std(betahat_mle(2,:)))     median(abs(betahat_mle(2,:)/beta1 - 1))      mean(T*NN1);...
      mean(betahatbc1(2,:))/beta1     median(betahatbc1(2,:))/beta1     std(betahatbc1(2,:)/beta1)    (1 - mean((betahatbc1(2,:) - 1.96*sqrt(s2_bc1(2,:)) <= beta1) & (betahatbc1(2,:) + 1.96*sqrt(s2_bc1(2,:)) >= beta1)))                           (1 - mean((betahatbc1(2,:) - 1.65*sqrt(s2_bc1(2,:)) <= beta1) & (betahatbc1(2,:) + 1.65*sqrt(s2_bc1(2,:)) >= beta1)))                       (mean(sqrt(s2_bc1(2,:)))/std(betahatbc1(2,:)))      median(abs(betahatbc1(2,:)/beta1 - 1))       mean(T*NN1) ;...
      mean(betahatbc2(2,:))/beta1     median(betahatbc2(2,:))/beta1     std(betahatbc2(2,:)/beta1)    (1 - mean((betahatbc2(2,:) - 1.96*sqrt(s2_bc2(2,:)) <= beta1) & (betahatbc2(2,:) + 1.96*sqrt(s2_bc2(2,:)) >= beta1)))                           (1 - mean((betahatbc2(2,:) - 1.65*sqrt(s2_bc2(2,:)) <= beta1) & (betahatbc2(2,:) + 1.65*sqrt(s2_bc2(2,:)) >= beta1)))                       (mean(sqrt(s2_bc2(2,:)))/std(betahatbc2(2,:)))      median(abs(betahatbc2(2,:)/beta1 - 1))       mean(T*NN1) ;...
      mean(betahatbc3(2,:))/beta1     median(betahatbc3(2,:))/beta1     std(betahatbc3(2,:)/beta1)    (1 - mean((betahatbc3(2,:) - 1.96*sqrt(s2_bc3(2,:)) <= beta1) & (betahatbc3(2,:) + 1.96*sqrt(s2_bc3(2,:)) >= beta1)))                           (1 - mean((betahatbc3(2,:) - 1.65*sqrt(s2_bc3(2,:)) <= beta1) & (betahatbc3(2,:) + 1.65*sqrt(s2_bc3(2,:)) >= beta1)))                       (mean(sqrt(s2_bc3(2,:)))/std(betahatbc3(2,:)))      median(abs(betahatbc3(2,:)/beta1 - 1))       mean(T*NN1) ])


disp('Table 1c: Coefficients beta2');
full([mean(betahat_mle0(3,:))/beta2   median(betahat_mle0(3,:))/beta2   std(betahat_mle0(3,:)/beta2)  (1 - mean((betahat_mle0(3,:) - 1.96*sqrt(s2_mle0(3,:)) <= beta2) & (betahat_mle0(3,:) + 1.96*sqrt(s2_mle0(3,:)) >= beta2)))                     (1 - mean((betahat_mle0(3,:) - 1.65*sqrt(s2_mle0(3,:)) <= beta2) & (betahat_mle0(3,:) + 1.65*sqrt(s2_mle0(3,:)) >= beta2)))                 (mean(sqrt(s2_mle0(3,:)))/std(betahat_mle0(3,:)))   median(abs(betahat_mle0(3,:)/beta2 - 1))     mean(T*NN1);...
      mean(betahat_mle1(3,:))/beta2   median(betahat_mle1(3,:))/beta2   std(betahat_mle1(3,:)/beta2)  (1 - mean((betahat_mle1(3,:) - 1.96*sqrt(s2_mle1(3,:)) <= beta2) & (betahat_mle1(3,:) + 1.96*sqrt(s2_mle1(3,:)) >= beta2)))                     (1 - mean((betahat_mle1(3,:) - 1.65*sqrt(s2_mle1(3,:)) <= beta2) & (betahat_mle1(3,:) + 1.65*sqrt(s2_mle1(3,:)) >= beta2)))                 (mean(sqrt(s2_mle1(3,:)))/std(betahat_mle1(3,:)))   median(abs(betahat_mle1(3,:)/beta2 - 1))     mean(T*NN1);...
      mean(betahat_mle(3,:))/beta2    median(betahat_mle(3,:))/beta2    std(betahat_mle(3,:)/beta2)   (1 - mean((betahat_mle(3,:) - 1.96*sqrt(s2_mle(3,:)) <= beta2) & (betahat_mle(3,:) + 1.96*sqrt(s2_mle(3,:)) >= beta2)))                         (1 - mean((betahat_mle(3,:) - 1.65*sqrt(s2_mle(3,:)) <= beta2) & (betahat_mle(3,:) + 1.65*sqrt(s2_mle(3,:)) >= beta2)))                     (mean(sqrt(s2_mle(3,:)))/std(betahat_mle(3,:)))     median(abs(betahat_mle(3,:)/beta2 - 1))      mean(T*NN1);...
      mean(betahatbc1(3,:))/beta2     median(betahatbc1(3,:))/beta2     std(betahatbc1(3,:)/beta2)    (1 - mean((betahatbc1(3,:) - 1.96*sqrt(s2_bc1(3,:)) <= beta2) & (betahatbc1(3,:) + 1.96*sqrt(s2_bc1(3,:)) >= beta2)))                           (1 - mean((betahatbc1(3,:) - 1.65*sqrt(s2_bc1(3,:)) <= beta2) & (betahatbc1(3,:) + 1.65*sqrt(s2_bc1(3,:)) >= beta2)))                       (mean(sqrt(s2_bc1(3,:)))/std(betahatbc1(3,:)))      median(abs(betahatbc1(3,:)/beta2 - 1))       mean(T*NN1) ;...
      mean(betahatbc2(3,:))/beta2     median(betahatbc2(3,:))/beta2     std(betahatbc2(3,:)/beta2)    (1 - mean((betahatbc2(3,:) - 1.96*sqrt(s2_bc2(3,:)) <= beta2) & (betahatbc2(3,:) + 1.96*sqrt(s2_bc2(3,:)) >= beta2)))                           (1 - mean((betahatbc2(3,:) - 1.65*sqrt(s2_bc2(3,:)) <= beta2) & (betahatbc2(3,:) + 1.65*sqrt(s2_bc2(3,:)) >= beta2)))                       (mean(sqrt(s2_bc2(3,:)))/std(betahatbc2(3,:)))      median(abs(betahatbc2(3,:)/beta2 - 1))       mean(T*NN1) ;...
      mean(betahatbc3(3,:))/beta2     median(betahatbc3(3,:))/beta2     std(betahatbc3(3,:)/beta2)    (1 - mean((betahatbc3(3,:) - 1.96*sqrt(s2_bc3(3,:)) <= beta2) & (betahatbc3(3,:) + 1.96*sqrt(s2_bc3(3,:)) >= beta2)))                           (1 - mean((betahatbc3(3,:) - 1.65*sqrt(s2_bc3(3,:)) <= beta2) & (betahatbc3(3,:) + 1.65*sqrt(s2_bc3(3,:)) >= beta2)))                       (mean(sqrt(s2_bc3(3,:)))/std(betahatbc3(3,:)))      median(abs(betahatbc3(3,:)/beta2 - 1))       mean(T*NN1) ])

disp('Table 1d: Coefficients rho');
full([mean(betahat_mle1(4,:))/rho   median(betahat_mle1(4,:))/rho   std(betahat_mle1(4,:)/rho)  (1 - mean((betahat_mle1(4,:) - 1.96*sqrt(s2_mle1(4,:)) <= rho) & (betahat_mle1(4,:) + 1.96*sqrt(s2_mle1(4,:)) >= rho)))                     (1 - mean((betahat_mle1(4,:) - 1.65*sqrt(s2_mle1(4,:)) <= rho) & (betahat_mle1(4,:) + 1.65*sqrt(s2_mle1(4,:)) >= rho)))                 (mean(sqrt(s2_mle1(4,:)))/std(betahat_mle1(4,:)))   median(abs(betahat_mle1(4,:)/rho - 1))     mean(T*NN1);...
      mean(betahat_mle(4,:))/rho    median(betahat_mle(4,:))/rho    std(betahat_mle(4,:)/rho)   (1 - mean((betahat_mle(4,:) - 1.96*sqrt(s2_mle(4,:)) <= rho) & (betahat_mle(4,:) + 1.96*sqrt(s2_mle(4,:)) >= rho)))                         (1 - mean((betahat_mle(4,:) - 1.65*sqrt(s2_mle(4,:)) <= rho) & (betahat_mle(4,:) + 1.65*sqrt(s2_mle(4,:)) >= rho)))                     (mean(sqrt(s2_mle(4,:)))/std(betahat_mle(4,:)))     median(abs(betahat_mle(4,:)/rho - 1))      mean(T*NN1);...
      mean(betahatbc1(4,:))/rho     median(betahatbc1(4,:))/rho     std(betahatbc1(4,:)/rho)    (1 - mean((betahatbc1(4,:) - 1.96*sqrt(s2_bc1(4,:)) <= rho) & (betahatbc1(4,:) + 1.96*sqrt(s2_bc1(4,:)) >= rho)))                           (1 - mean((betahatbc1(4,:) - 1.65*sqrt(s2_bc1(4,:)) <= rho) & (betahatbc1(4,:) + 1.65*sqrt(s2_bc1(4,:)) >= rho)))                       (mean(sqrt(s2_bc1(4,:)))/std(betahatbc1(4,:)))      median(abs(betahatbc1(4,:)/rho - 1))       mean(T*NN1) ;...
      mean(betahatbc2(4,:))/rho     median(betahatbc2(4,:))/rho     std(betahatbc2(4,:)/rho)    (1 - mean((betahatbc2(4,:) - 1.96*sqrt(s2_bc2(4,:)) <= rho) & (betahatbc2(4,:) + 1.96*sqrt(s2_bc2(4,:)) >= rho)))                           (1 - mean((betahatbc2(4,:) - 1.65*sqrt(s2_bc2(4,:)) <= rho) & (betahatbc2(4,:) + 1.65*sqrt(s2_bc2(4,:)) >= rho)))                       (mean(sqrt(s2_bc2(4,:)))/std(betahatbc2(4,:)))      median(abs(betahatbc2(4,:)/rho - 1))       mean(T*NN1) ;...
      mean(betahatbc3(4,:))/rho     median(betahatbc3(4,:))/rho     std(betahatbc3(4,:)/rho)    (1 - mean((betahatbc3(4,:) - 1.96*sqrt(s2_bc3(4,:)) <= rho) & (betahatbc3(4,:) + 1.96*sqrt(s2_bc3(4,:)) >= rho)))                           (1 - mean((betahatbc3(4,:) - 1.65*sqrt(s2_bc3(4,:)) <= rho) & (betahatbc3(4,:) + 1.65*sqrt(s2_bc3(4,:)) >= rho)))                       (mean(sqrt(s2_bc3(4,:)))/std(betahatbc3(4,:)))      median(abs(betahatbc3(4,:)/rho - 1))       mean(T*NN1) ])


save z:\selection\Results\CMLE\dynamic\fe_cmle_t3_b1000_mar30_2006

